import { OmekaConfig } from "./config.js";
import { Property } from "./factory.js";
import { Item, Thing } from "./thing.js";
export type Template = {
    id: number;
    label: string;
    class?: number;
    properties: Property[];
};
export type DataType = "uri" | "resource:item";
export type TemplateResponse = {
    "o:id": number;
    "o:label": string;
    "o:resource_class"?: {
        "@id": string;
        "o:id": number;
    };
    "o:resource_template_property": {
        "o:property": {
            "@id": string;
            "o:id": number;
        };
        "o:data_type"?: DataType[];
        "o:is_required": boolean;
    }[];
};
export declare class OmekaTemplates {
    private readonly config;
    readonly templates: {
        [id: number]: Template;
    };
    private partial_loaded;
    readonly partial_templates: {
        [id: number]: TemplateResponse;
    };
    readonly properties: {
        [id: number]: Property;
    };
    readonly items: {
        [id: number]: Item<any>;
    };
    constructor(config: OmekaConfig);
    preload_property(url: string): Promise<void>;
    preload_properties(): Promise<void>;
    get_property(id: number): Promise<Property>;
    transform_template(temp: TemplateResponse): Promise<Template>;
    preload_partial_templates(): Promise<void>;
    preload_templates(): Promise<void>;
    get_template(id: number): Promise<Template>;
    get_template_by_name(name: string): Promise<Template | undefined>;
    get_item(id: number, deep?: boolean): Promise<Item<any>>;
    get_items_set(item_set: number): Promise<Item<any>[]>;
    set_item<T extends Thing>(item: Item<T>): Item<T>;
}
